---
title: <span class="badge builder"></span> RegexMap
---
# <span class="badge builder"></span> RegexMap

## Constructor

```python
RegexMap()
```
## Methods

### <span class="badge object-method"></span> build

Builds the object.

```python
def build() -> dashboard.RegexMap
```

### <span class="badge object-method"></span> options

Regular expression to match against and the result to apply when the value matches the regex

```python
def options(options: cogbuilder.Builder[dashboard.DashboardRegexMapOptions]) -> typing.Self
```

## See also

 * <span class="badge object-type-class"></span> [RegexMap](./object-RegexMap.md)
